@@ -76,6 +76,7 @@ var searchData=
   ['clipboard',['clipboard',['../namespacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard.html',1,'com::sun::star::datatransfer']]],
   ['collatoroptions',['CollatorOptions',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1CollatorOptions.html',1,'com::sun::star::i18n']]],
   ['colorcomponenttag',['ColorComponentTag',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorComponentTag.html',1,'com::sun::star::rendering']]],
+  ['colorscaleentrytype',['ColorScaleEntryType',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html',1,'com::sun::star::sheet']]],
   ['colorspacetype',['ColorSpaceType',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorSpaceType.html',1,'com::sun::star::rendering']]],
   ['columnsearch',['ColumnSearch',['../namespacecom_1_1sun_1_1star_1_1sdbc_1_1ColumnSearch.html',1,'com::sun::star::sdbc']]],
   ['columnseparatorstyle',['ColumnSeparatorStyle',['../namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html',1,'com::sun::star::text']]],
@@ -91,6 +92,8 @@ var searchData=
   ['component',['component',['../namespacecom_1_1sun_1_1star_1_1form_1_1component.html',1,'com::sun::star::form']]],
   ['compositeoperation',['CompositeOperation',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1CompositeOperation.html',1,'com::sun::star::rendering']]],
   ['compositiontype',['CompositionType',['../namespacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1CompositionType.html',1,'com::sun::star::sdb::tools']]],
+  ['conditionentrytype',['ConditionEntryType',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html',1,'com::sun::star::sheet']]],
+  ['conditionformatoperator',['ConditionFormatOperator',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html',1,'com::sun::star::sheet']]],
   ['conditionoperator2',['ConditionOperator2',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html',1,'com::sun::star::sheet']]],
   ['configuration',['configuration',['../namespacecom_1_1sun_1_1star_1_1configuration.html',1,'com::sun::star']]],
   ['connection',['connection',['../namespacecom_1_1sun_1_1star_1_1connection.html',1,'com::sun::star']]],
@@ -112,6 +115,8 @@ var searchData=
   ['ctlscripttype',['CTLScriptType',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1CTLScriptType.html',1,'com::sun::star::i18n']]],
   ['cui',['cui',['../namespacecom_1_1sun_1_1star_1_1cui.html',1,'com::sun::star']]],
   ['data',['data',['../namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html',1,'com::sun::star::chart2']]],
+  ['databaraxis',['DataBarAxis',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarAxis.html',1,'com::sun::star::sheet']]],
+  ['databarentrytype',['DataBarEntryType',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html',1,'com::sun::star::sheet']]],
   ['databaseobject',['DatabaseObject',['../namespacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1DatabaseObject.html',1,'com::sun::star::sdb::application']]],
   ['databaseobjectcontainer',['DatabaseObjectContainer',['../namespacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1DatabaseObjectContainer.html',1,'com::sun::star::sdb::application']]],
   ['datalabelplacement',['DataLabelPlacement',['../namespacecom_1_1sun_1_1star_1_1chart_1_1DataLabelPlacement.html',1,'com::sun::star::chart']]],
@@ -129,6 +134,7 @@ var searchData=
   ['datatype',['DataType',['../namespacecom_1_1sun_1_1star_1_1sdbc_1_1DataType.html',1,'com::sun::star::sdbc']]],
   ['datatypeclass',['DataTypeClass',['../namespacecom_1_1sun_1_1star_1_1xsd_1_1DataTypeClass.html',1,'com::sun::star::xsd']]],
   ['datedisplayformat',['DateDisplayFormat',['../namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html',1,'com::sun::star::text']]],
+  ['datetype',['DateType',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html',1,'com::sun::star::sheet']]],
   ['deferrability',['Deferrability',['../namespacecom_1_1sun_1_1star_1_1sdbc_1_1Deferrability.html',1,'com::sun::star::sdbc']]],
   ['deployment',['deployment',['../namespacecom_1_1sun_1_1star_1_1deployment.html',1,'com::sun::star']]],
   ['devicecapability',['DeviceCapability',['../namespacecom_1_1sun_1_1star_1_1awt_1_1DeviceCapability.html',1,'com::sun::star::awt']]],
@@ -188,8 +194,7 @@ var searchData=
   ['fontemphasismark',['FontEmphasisMark',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontEmphasisMark.html',1,'com::sun::star::awt']]],
   ['fontfamily',['FontFamily',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontFamily.html',1,'com::sun::star::awt']]],
   ['fontpitch',['FontPitch',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontPitch.html',1,'com::sun::star::awt']]],
-  ['fontrelief',['FontRelief',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontRelief.html',1,'com::sun::star::awt']]],
-  ['fontrelief',['FontRelief',['../namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html',1,'com::sun::star::text']]],
+  ['fontrelief',['FontRelief',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontRelief.html',1,'com::sun::star::awt::FontRelief'],['../namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html',1,'com::sun::star::text::FontRelief']]],
   ['fontstrikeout',['FontStrikeout',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontStrikeout.html',1,'com::sun::star::awt']]],
   ['fonttype',['FontType',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontType.html',1,'com::sun::star::awt']]],
   ['fontunderline',['FontUnderline',['../namespacecom_1_1sun_1_1star_1_1awt_1_1FontUnderline.html',1,'com::sun::star::awt']]],
@@ -221,6 +226,8 @@ var searchData=
   ['groupon',['GroupOn',['../namespacecom_1_1sun_1_1star_1_1report_1_1GroupOn.html',1,'com::sun::star::report']]],
   ['horiorientation',['HoriOrientation',['../namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html',1,'com::sun::star::text']]],
   ['i18n',['i18n',['../namespacecom_1_1sun_1_1star_1_1i18n.html',1,'com::sun::star']]],
+  ['iconsetformatentry',['IconSetFormatEntry',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html',1,'com::sun::star::sheet']]],
+  ['iconsettype',['IconSetType',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html',1,'com::sun::star::sheet']]],
   ['image',['image',['../namespacecom_1_1sun_1_1star_1_1image.html',1,'com::sun::star']]],
   ['imagealign',['ImageAlign',['../namespacecom_1_1sun_1_1star_1_1awt_1_1ImageAlign.html',1,'com::sun::star::awt']]],
   ['imagedrawmode',['ImageDrawMode',['../namespacecom_1_1sun_1_1star_1_1awt_1_1ImageDrawMode.html',1,'com::sun::star::awt']]],
@@ -231,9 +238,7 @@ var searchData=
   ['indextype',['IndexType',['../namespacecom_1_1sun_1_1star_1_1sdbc_1_1IndexType.html',1,'com::sun::star::sdbc']]],
   ['input',['input',['../namespacecom_1_1sun_1_1star_1_1xml_1_1input.html',1,'com::sun::star::xml']]],
   ['inputsequencecheckmode',['InputSequenceCheckMode',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1InputSequenceCheckMode.html',1,'com::sun::star::i18n']]],
-  ['inspection',['inspection',['../namespacecom_1_1sun_1_1star_1_1report_1_1inspection.html',1,'com::sun::star::report']]],
-  ['inspection',['inspection',['../namespacecom_1_1sun_1_1star_1_1form_1_1inspection.html',1,'com::sun::star::form']]],
-  ['inspection',['inspection',['../namespacecom_1_1sun_1_1star_1_1inspection.html',1,'com::sun::star']]],
+  ['inspection',['inspection',['../namespacecom_1_1sun_1_1star_1_1form_1_1inspection.html',1,'com::sun::star::form::inspection'],['../namespacecom_1_1sun_1_1star_1_1inspection.html',1,'com::sun::star::inspection'],['../namespacecom_1_1sun_1_1star_1_1report_1_1inspection.html',1,'com::sun::star::report::inspection']]],
   ['interpolationmode',['InterpolationMode',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1InterpolationMode.html',1,'com::sun::star::rendering']]],
   ['invalidatestyle',['InvalidateStyle',['../namespacecom_1_1sun_1_1star_1_1awt_1_1InvalidateStyle.html',1,'com::sun::star::awt']]],
   ['io',['io',['../namespacecom_1_1sun_1_1star_1_1io.html',1,'com::sun::star']]],
@@ -318,7 +323,6 @@ var searchData=
   ['pathjointype',['PathJoinType',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1PathJoinType.html',1,'com::sun::star::rendering']]],
   ['placeholdertype',['PlaceholderType',['../namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html',1,'com::sun::star::text']]],
   ['plugin',['plugin',['../namespacecom_1_1sun_1_1star_1_1plugin.html',1,'com::sun::star']]],
-  ['pluginmode',['PluginMode',['../namespacecom_1_1sun_1_1star_1_1plugin_1_1PluginMode.html',1,'com::sun::star::plugin']]],
   ['popupmenudirection',['PopupMenuDirection',['../namespacecom_1_1sun_1_1star_1_1awt_1_1PopupMenuDirection.html',1,'com::sun::star::awt']]],
   ['positionandspacemode',['PositionAndSpaceMode',['../namespacecom_1_1sun_1_1star_1_1text_1_1PositionAndSpaceMode.html',1,'com::sun::star::text']]],
   ['positionlayoutdir',['PositionLayoutDir',['../namespacecom_1_1sun_1_1star_1_1text_1_1PositionLayoutDir.html',1,'com::sun::star::text']]],
@@ -359,8 +363,7 @@ var searchData=
   ['ruleaction',['RuleAction',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleAction.html',1,'com::sun::star::ucb']]],
   ['ruleoperator',['RuleOperator',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleOperator.html',1,'com::sun::star::ucb']]],
   ['runtime',['runtime',['../namespacecom_1_1sun_1_1star_1_1form_1_1runtime.html',1,'com::sun::star::form']]],
-  ['sax',['sax',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax.html',1,'com::sun::star::xml::crypto']]],
-  ['sax',['sax',['../namespacecom_1_1sun_1_1star_1_1xml_1_1sax.html',1,'com::sun::star::xml']]],
+  ['sax',['sax',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax.html',1,'com::sun::star::xml::crypto::sax'],['../namespacecom_1_1sun_1_1star_1_1xml_1_1sax.html',1,'com::sun::star::xml::sax']]],
   ['scanner',['scanner',['../namespacecom_1_1sun_1_1star_1_1scanner.html',1,'com::sun::star']]],
   ['schemaattribute',['SchemaAttribute',['../namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SchemaAttribute.html',1,'com::sun::star::configuration::backend']]],
   ['script',['script',['../namespacecom_1_1sun_1_1star_1_1script.html',1,'com::sun::star']]],
@@ -371,6 +374,7 @@ var searchData=
   ['sdb',['sdb',['../namespacecom_1_1sun_1_1star_1_1sdb.html',1,'com::sun::star']]],
   ['sdbc',['sdbc',['../namespacecom_1_1sun_1_1star_1_1sdbc.html',1,'com::sun::star']]],
   ['sdbcx',['sdbcx',['../namespacecom_1_1sun_1_1star_1_1sdbcx.html',1,'com::sun::star']]],
+  ['searchalgorithms2',['SearchAlgorithms2',['../namespacecom_1_1sun_1_1star_1_1util_1_1SearchAlgorithms2.html',1,'com::sun::star::util']]],
   ['searchflags',['SearchFlags',['../namespacecom_1_1sun_1_1star_1_1util_1_1SearchFlags.html',1,'com::sun::star::util']]],
   ['sectionpagebreak',['SectionPageBreak',['../namespacecom_1_1sun_1_1star_1_1report_1_1SectionPageBreak.html',1,'com::sun::star::report']]],
   ['security',['security',['../namespacecom_1_1sun_1_1star_1_1security.html',1,'com::sun::star']]],
@@ -389,8 +393,7 @@ var searchData=
   ['status',['status',['../namespacecom_1_1sun_1_1star_1_1frame_1_1status.html',1,'com::sun::star::frame']]],
   ['statusbarfunction',['StatusBarFunction',['../namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html',1,'com::sun::star::sheet']]],
   ['storageformats',['StorageFormats',['../namespacecom_1_1sun_1_1star_1_1embed_1_1StorageFormats.html',1,'com::sun::star::embed']]],
-  ['style',['style',['../namespacecom_1_1sun_1_1star_1_1style.html',1,'com::sun::star']]],
-  ['style',['Style',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Style.html',1,'com::sun::star::awt']]],
+  ['style',['Style',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Style.html',1,'com::sun::star::awt::Style'],['../namespacecom_1_1sun_1_1star_1_1style.html',1,'com::sun::star::style']]],
   ['submission',['submission',['../namespacecom_1_1sun_1_1star_1_1form_1_1submission.html',1,'com::sun::star::form']]],
   ['sun',['sun',['../namespacecom_1_1sun.html',1,'com']]],
   ['svg',['svg',['../namespacecom_1_1sun_1_1star_1_1svg.html',1,'com::sun::star']]],
@@ -411,12 +414,12 @@ var searchData=
   ['textconversionoption',['TextConversionOption',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1TextConversionOption.html',1,'com::sun::star::i18n']]],
   ['textconversiontype',['TextConversionType',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1TextConversionType.html',1,'com::sun::star::i18n']]],
   ['textdirection',['TextDirection',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1TextDirection.html',1,'com::sun::star::rendering']]],
-  ['textfield',['textfield',['../namespacecom_1_1sun_1_1star_1_1text_1_1textfield.html',1,'com::sun::star::text']]],
-  ['textfield',['textfield',['../namespacecom_1_1sun_1_1star_1_1presentation_1_1textfield.html',1,'com::sun::star::presentation']]],
+  ['textfield',['textfield',['../namespacecom_1_1sun_1_1star_1_1presentation_1_1textfield.html',1,'com::sun::star::presentation::textfield'],['../namespacecom_1_1sun_1_1star_1_1text_1_1textfield.html',1,'com::sun::star::text::textfield']]],
   ['textgridmode',['TextGridMode',['../namespacecom_1_1sun_1_1star_1_1text_1_1TextGridMode.html',1,'com::sun::star::text']]],
   ['textmarkuptype',['TextMarkupType',['../namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html',1,'com::sun::star::text']]],
   ['texturingmode',['TexturingMode',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1TexturingMode.html',1,'com::sun::star::rendering']]],
   ['tickmarkstyle',['TickmarkStyle',['../namespacecom_1_1sun_1_1star_1_1chart2_1_1TickmarkStyle.html',1,'com::sun::star::chart2']]],
+  ['tiledrendering',['tiledrendering',['../namespacecom_1_1sun_1_1star_1_1tiledrendering.html',1,'com::sun::star']]],
   ['timedisplayformat',['TimeDisplayFormat',['../namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html',1,'com::sun::star::text']]],
   ['timeunit',['TimeUnit',['../namespacecom_1_1sun_1_1star_1_1chart_1_1TimeUnit.html',1,'com::sun::star::chart']]],
   ['tolerantpropertysetresulttype',['TolerantPropertySetResultType',['../namespacecom_1_1sun_1_1star_1_1beans_1_1TolerantPropertySetResultType.html',1,'com::sun::star::beans']]],
@@ -429,8 +432,7 @@ var searchData=
   ['tree',['tree',['../namespacecom_1_1sun_1_1star_1_1awt_1_1tree.html',1,'com::sun::star::awt']]],
   ['type',['Type',['../namespacecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Type.html',1,'com::sun::star::text::textfield']]],
   ['ucb',['ucb',['../namespacecom_1_1sun_1_1star_1_1ucb.html',1,'com::sun::star']]],
-  ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1ui.html',1,'com::sun::star::deployment']]],
-  ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1ui.html',1,'com::sun::star']]],
+  ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1ui.html',1,'com::sun::star::deployment::ui'],['../namespacecom_1_1sun_1_1star_1_1ui.html',1,'com::sun::star::ui']]],
   ['uielementtype',['UIElementType',['../namespacecom_1_1sun_1_1star_1_1ui_1_1UIElementType.html',1,'com::sun::star::ui']]],
   ['unicodetype',['UnicodeType',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1UnicodeType.html',1,'com::sun::star::i18n']]],
   ['uno',['uno',['../namespacecom_1_1sun_1_1star_1_1uno.html',1,'com::sun::star']]],
@@ -462,8 +464,7 @@ var searchData=
   ['wrapper',['wrapper',['../namespacecom_1_1sun_1_1star_1_1xml_1_1wrapper.html',1,'com::sun::star::xml']]],
   ['writingmode2',['WritingMode2',['../namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html',1,'com::sun::star::text']]],
   ['xforms',['xforms',['../namespacecom_1_1sun_1_1star_1_1xforms.html',1,'com::sun::star']]],
-  ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1xml.html',1,'com::sun::star']]],
-  ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1xml.html',1,'com::sun::star::configuration::backend']]],
+  ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1xml.html',1,'com::sun::star::configuration::backend::xml'],['../namespacecom_1_1sun_1_1star_1_1xml.html',1,'com::sun::star::xml']]],
   ['xpath',['xpath',['../namespacecom_1_1sun_1_1star_1_1xml_1_1xpath.html',1,'com::sun::star::xml']]],
   ['xsd',['xsd',['../namespacecom_1_1sun_1_1star_1_1xsd.html',1,'com::sun::star']]],
   ['xslt',['xslt',['../namespacecom_1_1sun_1_1star_1_1xml_1_1xslt.html',1,'com::sun::star::xml']]],
